/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 03393
 |               DRUG SERVICES RESEARCH SURVEY (DSRS), 1990
 |           (DATASET 0002: PHASE II - ADMINISTRATOR INTERVIEW)
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE q1_cor    -9='(-9) NOT ASCERTAINED' 1='(1) YES' 2='(2) NO' ;
  VALUE q2ffffff  -9='(-9) NOT ASCERTAINED' 1='(1) DRUG ONLY' 2='(2) ALCOHOL ONLY'
                  3='(3) BOTH DRUG AND ALCOHOL' ;
  VALUE q3_sep    -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX BOTH DRUG AND ALCOHOL CLIENTS'
                  1='(1) YES' 2='(2) NO' ;
  VALUE q4_dif    -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX BOTH DRUG AND ALCOHOL CLIENTS'
                  1='(1) YES' 2='(2) NO' ;
  VALUE q5_drug   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - BOTH DRUG & ALC CLIENTS NOT TX OR NOT SEPARATED'
                  1='(1) DRUG PROTOCOL DESCRIBED' ;
  VALUE q5_alc    -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - BOTH DRUG & ALC CLIENTS NOT TX OR NOT SEPARATED'
                  1='(1) ALCOHOL PROTOCOL DESCRIBED' ;
  VALUE q6_cor    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q6a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - FIGURE FROM TELEPHONE INT IS CORRECT' ;
  VALUE q7_cor    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q7a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - FIGURE FROM TELEPHONE INT IS CORRECT' 0='(0) NONE' ;
  VALUE q8ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' ;
  VALUE q9ffffff  -9='(-9) NOT ASCERTAINED - MISSING' -8='(-8) DON''T KNOW' 1='(1) MORE'
                  2='(2) LESS' 3='(3) ABOUT THE SAME' ;
  VALUE q10a_hdd  -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_hdd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDD' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_hdd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDD' ;
  VALUE q10a_hdf  -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_hdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDF' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_hdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDF' ;
  VALUE q10a_rdd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_rdd  -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDD' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_rdd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDD' ;
  VALUE q10a_rdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_rdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDF' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_rdf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDF' ;
  VALUE q10a_odd  -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_odd  -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODD' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_odd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODD' ;
  VALUE q10a_odm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_odm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODM' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_odm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODM' ;
  VALUE q10a_odf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10b_odf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODF' 1='(1) YES' 2='(2) NO' ;
  VALUE q10c_odf  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODF' ;
  VALUE q11_hdd   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDD'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_hdf   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE HDF'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_rdd   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDD'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_rdf   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE RDF'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_odd   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODD'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_odm   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODM'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q11_odf   -9='(-9) NOT ASCERTAINED'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ODF'
                  0='(0) BOX NOT CHECKED, PRESUMED NO'
                  1='(1) WAITING LIST POLICY DESCRIBED' ;
  VALUE q12a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q12b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q12c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q12d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES (SPECIFY)'
                  2='(2) NO' ;
  VALUE q13a      1='(1) YES' 2='(2) NO' ;
  VALUE q13a_tns  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX TEENS' 1='(1) YES' 2='(2) NO' ;
  VALUE q13b      -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q13b_prg  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX PREGNANT WOMEN' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q13c      -9='(-9) NOT ASCERTAINED' 1='(1) YES' 2='(2) NO' ;
  VALUE q13c_ivd  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX IV DRUG USERS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q13d      -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q13d_ddc  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT TX DUAL DX PXS' 1='(1) YES' 2='(2) NO' ;
  VALUE q13e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q14a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q14b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q14c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q15_cert  -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q15a      -9='(-9) NOT ASCERRTAINED'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COUNSELORS W/ SPECIAL CERTS'
                  1='(1) DESCRIPTION OF SPECIAL CERTIFICATION GIVEN' ;
  VALUE q16_comp  1='(1) YES' 2='(2) NO' ;
  VALUE q17a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q17b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q17c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q17d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q18_own   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) PUBLICLY OWNED'
                  2='(2) PRIVATELY OWNED, NON-PROFIT'
                  3='(3) PRIVATELY OWNED, FOR PROFIT' ;
  VALUE q19a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19f      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES (SPECIFY)'
                  2='(2) NO' ;
  VALUE q20a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q20b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q20c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES (SPECIFY)'
                  2='(2) NO' ;
  VALUE q21_othu  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q22_mult  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q23a_1ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23a_2ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23a_3ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23a_4ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23a_5ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_1ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_2ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_3ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_4ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23b_5ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23c_1ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23c_2ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE q23c_3ff  -9='(-9) NOT ASCERTAINED' -7='(-7) REFUSED' 1='(1) GIVEN' 2='(2) DO NOT HAVE' ;
  VALUE corrfac   0='(0) NO' 1='(1) YES' ;
  VALUE alchonly  0='(0) NO' 1='(1) YES' ;
  VALUE stratum   1='(1) HOSPITAL IN-PATIENT DRUG TREATMENT'
                  2='(2) RESIDENTIAL DRUG TREATMENT'
                  3='(3) OUT-PATIENT DRUG DETOXIFICATION MAINTENANCE'
                  4='(4) OUT-PATIENT DRUG-FREE TREATMENT'
                  5='(5) ALCOHOL TREATMENT ONLY' 6='(6) UNKNOWN TREATMENT TYPE' ;
  VALUE region    1='(1) NORTHEAST' 2='(2) NORTH CENTRAL' 3='(3) SOUTH' 4='(4) WEST' ;
  VALUE qa1fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa1a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QA1' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qa2fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa3fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa3a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QA3' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qa4fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa4a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QA4' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qa5fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa5a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 2, 8 OR 9 IN QA5' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qa6fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qa6a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 2, 8 OR 9 IN QA6A' 1='(1) YES'
                  2='(2) NO' ;
  VALUE qb1fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE qb1a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QB1' 1='(1) YES'
                  2='(2) NO' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (OBS_NUM <= -1) THEN OBS_NUM = .;
   IF (Q1_COR <= -1) THEN Q1_COR = .;
   IF (Q2 <= -1) THEN Q2 = .;
   IF (Q3_SEP <= -1) THEN Q3_SEP = .;
   IF (Q4_DIF <= -1) THEN Q4_DIF = .;
   IF (Q5_DRUG <= -1) THEN Q5_DRUG = .;
   IF (Q5_ALC <= -1) THEN Q5_ALC = .;
   IF (Q6_COR <= -1) THEN Q6_COR = .;
   IF (Q6A <= -1) THEN Q6A = .;
   IF (Q7_COR <= -1) THEN Q7_COR = .;
   IF (Q7A <= -1) THEN Q7A = .;
   IF (Q8 <= -1) THEN Q8 = .;
   IF (Q9 <= -1) THEN Q9 = .;
   IF (Q10A_HDD <= -1) THEN Q10A_HDD = .;
   IF (Q10B_HDD <= -1) THEN Q10B_HDD = .;
   IF (Q10C_HDD <= -1) THEN Q10C_HDD = .;
   IF (Q10A_HDF <= -1) THEN Q10A_HDF = .;
   IF (Q10B_HDF <= -1) THEN Q10B_HDF = .;
   IF (Q10C_HDF <= -1) THEN Q10C_HDF = .;
   IF (Q10A_RDD <= -1) THEN Q10A_RDD = .;
   IF (Q10B_RDD <= -1) THEN Q10B_RDD = .;
   IF (Q10C_RDD <= -1) THEN Q10C_RDD = .;
   IF (Q10A_RDF <= -1) THEN Q10A_RDF = .;
   IF (Q10B_RDF <= -1) THEN Q10B_RDF = .;
   IF (Q10C_RDF <= -1) THEN Q10C_RDF = .;
   IF (Q10A_ODD <= -1) THEN Q10A_ODD = .;
   IF (Q10B_ODD <= -1) THEN Q10B_ODD = .;
   IF (Q10C_ODD <= -1) THEN Q10C_ODD = .;
   IF (Q10A_ODM <= -1) THEN Q10A_ODM = .;
   IF (Q10B_ODM <= -1) THEN Q10B_ODM = .;
   IF (Q10C_ODM <= -1) THEN Q10C_ODM = .;
   IF (Q10A_ODF <= -1) THEN Q10A_ODF = .;
   IF (Q10B_ODF <= -1) THEN Q10B_ODF = .;
   IF (Q10C_ODF <= -1) THEN Q10C_ODF = .;
   IF (Q11_HDD <= -1) THEN Q11_HDD = .;
   IF (Q11_HDF <= -1) THEN Q11_HDF = .;
   IF (Q11_RDD <= -1) THEN Q11_RDD = .;
   IF (Q11_RDF <= -1) THEN Q11_RDF = .;
   IF (Q11_ODD <= -1) THEN Q11_ODD = .;
   IF (Q11_ODM <= -1) THEN Q11_ODM = .;
   IF (Q11_ODF <= -1) THEN Q11_ODF = .;
   IF (Q12A <= -1) THEN Q12A = .;
   IF (Q12B <= -1) THEN Q12B = .;
   IF (Q12C <= -1) THEN Q12C = .;
   IF (Q12D <= -1) THEN Q12D = .;
   IF (Q13A <= -1) THEN Q13A = .;
   IF (Q13A_TNS <= -1) THEN Q13A_TNS = .;
   IF (Q13B <= -1) THEN Q13B = .;
   IF (Q13B_PRG <= -1) THEN Q13B_PRG = .;
   IF (Q13C <= -1) THEN Q13C = .;
   IF (Q13C_IVD <= -1) THEN Q13C_IVD = .;
   IF (Q13D <= -1) THEN Q13D = .;
   IF (Q13D_DDC <= -1) THEN Q13D_DDC = .;
   IF (Q13E <= -1) THEN Q13E = .;
   IF (Q14A <= -1) THEN Q14A = .;
   IF (Q14B <= -1) THEN Q14B = .;
   IF (Q14C <= -1) THEN Q14C = .;
   IF (Q15_CERT <= -1) THEN Q15_CERT = .;
   IF (Q15A <= -1) THEN Q15A = .;
   IF (Q16_COMP <= -1) THEN Q16_COMP = .;
   IF (Q17A <= -1) THEN Q17A = .;
   IF (Q17B <= -1) THEN Q17B = .;
   IF (Q17C <= -1) THEN Q17C = .;
   IF (Q17D <= -1) THEN Q17D = .;
   IF (Q18_OWN <= -1) THEN Q18_OWN = .;
   IF (Q19A <= -1) THEN Q19A = .;
   IF (Q19B <= -1) THEN Q19B = .;
   IF (Q19C <= -1) THEN Q19C = .;
   IF (Q19D <= -1) THEN Q19D = .;
   IF (Q19E <= -1) THEN Q19E = .;
   IF (Q19F <= -1) THEN Q19F = .;
   IF (Q20A <= -1) THEN Q20A = .;
   IF (Q20B <= -1) THEN Q20B = .;
   IF (Q20C <= -1) THEN Q20C = .;
   IF (Q21_OTHU <= -1) THEN Q21_OTHU = .;
   IF (Q22_MULT <= -1) THEN Q22_MULT = .;
   IF (Q23A_1 <= -1) THEN Q23A_1 = .;
   IF (Q23A_2 <= -1) THEN Q23A_2 = .;
   IF (Q23A_3 <= -1) THEN Q23A_3 = .;
   IF (Q23A_4 <= -1) THEN Q23A_4 = .;
   IF (Q23A_5 <= -1) THEN Q23A_5 = .;
   IF (Q23B_1 <= -1) THEN Q23B_1 = .;
   IF (Q23B_2 <= -1) THEN Q23B_2 = .;
   IF (Q23B_3 <= -1) THEN Q23B_3 = .;
   IF (Q23B_4 <= -1) THEN Q23B_4 = .;
   IF (Q23B_5 <= -1) THEN Q23B_5 = .;
   IF (Q23C_1 <= -1) THEN Q23C_1 = .;
   IF (Q23C_2 <= -1) THEN Q23C_2 = .;
   IF (Q23C_3 <= -1) THEN Q23C_3 = .;
   IF (CORRFAC <= -1) THEN CORRFAC = .;
   IF (ALCHONLY <= -1) THEN ALCHONLY = .;
   IF (STRATUM <= -1) THEN STRATUM = .;
   IF (REGION <= -1) THEN REGION = .;
   IF (QA1 <= -1) THEN QA1 = .;
   IF (QA1A <= -1) THEN QA1A = .;
   IF (QA2 <= -1) THEN QA2 = .;
   IF (QA3 <= -1) THEN QA3 = .;
   IF (QA3A <= -1) THEN QA3A = .;
   IF (QA4 <= -1) THEN QA4 = .;
   IF (QA4A <= -1) THEN QA4A = .;
   IF (QA5 <= -1) THEN QA5 = .;
   IF (QA5A <= -1) THEN QA5A = .;
   IF (QA6 <= -1) THEN QA6 = .;
   IF (QA6A <= -1) THEN QA6A = .;
   IF (QB1 <= -1) THEN QB1 = .;
   IF (QB1A <= -1) THEN QB1A = .;
   IF (REP_STRA <= -1) THEN REP_STRA = .;
   IF (VWGHT <= -1.00000) THEN VWGHT = .;
   IF (VWT1 <= -1.00000) THEN VWT1 = .;
   IF (VWT2 <= -1.00000) THEN VWT2 = .;
   IF (VWT3 <= -1.00000) THEN VWT3 = .;
   IF (VWT4 <= -1.00000) THEN VWT4 = .;
   IF (VWT5 <= -1.00000) THEN VWT5 = .;
   IF (VWT6 <= -1.00000) THEN VWT6 = .;
   IF (VWT7 <= -1.00000) THEN VWT7 = .;
   IF (VWT8 <= -1.00000) THEN VWT8 = .;
   IF (VWT9 <= -1.00000) THEN VWT9 = .;
   IF (VWT10 <= -1.00000) THEN VWT10 = .;
   IF (VWT11 <= -1.00000) THEN VWT11 = .;
   IF (VWT12 <= -1.00000) THEN VWT12 = .;
   IF (VWT13 <= -1.00000) THEN VWT13 = .;
   IF (VWT14 <= -1.00000) THEN VWT14 = .;
   IF (VWT15 <= -1.00000) THEN VWT15 = .;
   IF (VWT16 <= -1.00000) THEN VWT16 = .;
   IF (VWT17 <= -1.00000) THEN VWT17 = .;
   IF (VWT18 <= -1.00000) THEN VWT18 = .;
   IF (VWT19 <= -1.00000) THEN VWT19 = .;
   IF (VWT20 <= -1.00000) THEN VWT20 = .;
   IF (VWT21 <= -1.00000) THEN VWT21 = .;
   IF (VWT22 <= -1.00000) THEN VWT22 = .;
   IF (VWT23 <= -1.00000) THEN VWT23 = .;
   IF (VWT24 <= -1.00000) THEN VWT24 = .;
   IF (VWT25 <= -1.00000) THEN VWT25 = .;
   IF (VWT26 <= -1.00000) THEN VWT26 = .;
   IF (VWT27 <= -1.00000) THEN VWT27 = .;
   IF (VWT28 <= -1.00000) THEN VWT28 = .;
   IF (VWT29 <= -1.00000) THEN VWT29 = .;
   IF (VWT30 <= -1.00000) THEN VWT30 = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT Q1_COR q1_cor. Q2 q2ffffff. Q3_SEP q3_sep.
         Q4_DIF q4_dif. Q5_DRUG q5_drug. Q5_ALC q5_alc.
         Q6_COR q6_cor. Q6A q6a. Q7_COR q7_cor.
         Q7A q7a. Q8 q8ffffff. Q9 q9ffffff.
         Q10A_HDD q10a_hdd. Q10B_HDD q10b_hdd. Q10C_HDD q10c_hdd.
         Q10A_HDF q10a_hdf. Q10B_HDF q10b_hdf. Q10C_HDF q10c_hdf.
         Q10A_RDD q10a_rdd. Q10B_RDD q10b_rdd. Q10C_RDD q10c_rdd.
         Q10A_RDF q10a_rdf. Q10B_RDF q10b_rdf. Q10C_RDF q10c_rdf.
         Q10A_ODD q10a_odd. Q10B_ODD q10b_odd. Q10C_ODD q10c_odd.
         Q10A_ODM q10a_odm. Q10B_ODM q10b_odm. Q10C_ODM q10c_odm.
         Q10A_ODF q10a_odf. Q10B_ODF q10b_odf. Q10C_ODF q10c_odf.
         Q11_HDD q11_hdd. Q11_HDF q11_hdf. Q11_RDD q11_rdd.
         Q11_RDF q11_rdf. Q11_ODD q11_odd. Q11_ODM q11_odm.
         Q11_ODF q11_odf. Q12A q12a. Q12B q12b.
         Q12C q12c. Q12D q12d. Q13A q13a.
         Q13A_TNS q13a_tns. Q13B q13b. Q13B_PRG q13b_prg.
         Q13C q13c. Q13C_IVD q13c_ivd. Q13D q13d.
         Q13D_DDC q13d_ddc. Q13E q13e. Q14A q14a.
         Q14B q14b. Q14C q14c. Q15_CERT q15_cert.
         Q15A q15a. Q16_COMP q16_comp. Q17A q17a.
         Q17B q17b. Q17C q17c. Q17D q17d.
         Q18_OWN q18_own. Q19A q19a. Q19B q19b.
         Q19C q19c. Q19D q19d. Q19E q19e.
         Q19F q19f. Q20A q20a. Q20B q20b.
         Q20C q20c. Q21_OTHU q21_othu. Q22_MULT q22_mult.
         Q23A_1 q23a_1ff. Q23A_2 q23a_2ff. Q23A_3 q23a_3ff.
         Q23A_4 q23a_4ff. Q23A_5 q23a_5ff. Q23B_1 q23b_1ff.
         Q23B_2 q23b_2ff. Q23B_3 q23b_3ff. Q23B_4 q23b_4ff.
         Q23B_5 q23b_5ff. Q23C_1 q23c_1ff. Q23C_2 q23c_2ff.
         Q23C_3 q23c_3ff. CORRFAC corrfac. ALCHONLY alchonly.
         STRATUM stratum. REGION region. QA1 qa1fffff.
         QA1A qa1a. QA2 qa2fffff. QA3 qa3fffff.
         QA3A qa3a. QA4 qa4fffff. QA4A qa4a.
         QA5 qa5fffff. QA5A qa5a. QA6 qa6fffff.
         QA6A qa6a. QB1 qb1fffff. QB1A qb1a.
          ;

RUN ;
